SocketAddress

Struct SocketAddress 

pub struct SocketAddress {
    pub ip_addr: IpAddr,
    pub port: u16,
}
An IpAddr with an associated port (u16)

Fields

ip_addr: IpAddrport: u16

Implementations

Source

impl SocketAddress

pub const fn new(ip_addr: IpAddr, port: u16) -> Self

creates a new SocketAddress

pub const fn local_ipv4(port: u16) -> Self

creates a new local ipv4 SocketAddress for the given port

Example
use rama_net::address::SocketAddress;

let addr = SocketAddress::local_ipv4(8080);
assert_eq!("127.0.0.1:8080", addr.to_string());
pub const fn local_ipv6(port: u16) -> Self

creates a new local ipv6 SocketAddress for the given port.

Example
use rama_net::address::SocketAddress;

let addr = SocketAddress::local_ipv6(8080);
assert_eq!("[::1]:8080", addr.to_string());
pub const fn default_ipv4(port: u16) -> Self

creates a new default ipv4 SocketAddress for the given port

Example
use rama_net::address::SocketAddress;

let addr = SocketAddress::default_ipv4(8080);
assert_eq!("0.0.0.0:8080", addr.to_string());
pub const fn default_ipv6(port: u16) -> Self

creates a new default ipv6 SocketAddress for the given port.

Example
use rama_net::address::SocketAddress;

let addr = SocketAddress::default_ipv6(8080);
assert_eq!("[::]:8080", addr.to_string());
pub fn has_private_ip_addr(self) -> bool

Returns true when the SocketAddress’s ip address belongs to a range that should be treated as private instead of a normal public-Internet destination.

pub fn from_std(addr: SocketAddr) -> Self

Create a SocketAddress from the std SocketAddr version.

pub fn into_std(self) -> SocketAddr

Turn the SocketAddress into the std SocketAddr version.

pub const fn broadcast_ipv4(port: u16) -> Self

creates a new broadcast ipv4 SocketAddress for the given port

Example
use rama_net::address::SocketAddress;

let addr = SocketAddress::broadcast_ipv4(8080);
assert_eq!("255.255.255.255:8080", addr.to_string());
pub fn with_ip(self, ip_addr: IpAddr) -> Self

Set IpAddr as the ip of SocketAddress

pub fn set_ip(&mut self, ip_addr: IpAddr) -> &mut Self

Set IpAddr as the ip of SocketAddress

pub fn with_ipv4(self, ip_addr: Ipv4Addr) -> Self

Set Ipv4Addr as the ip of SocketAddress

pub fn set_ipv4(&mut self, ip_addr: Ipv4Addr) -> &mut Self

Set Ipv4Addr as the ip of SocketAddress

pub fn with_ipv6(self, ip_addr: Ipv6Addr) -> Self

Set Ipv6Addr as the ip of SocketAddress

pub fn set_ipv6(&mut self, ip_addr: Ipv6Addr) -> &mut Self

Set Ipv6Addr as the ip of SocketAddress

pub fn with_port(self, port: u16) -> Self

Set port (u16) of SocketAddress

pub fn set_port(&mut self, port: u16) -> &mut Self

Set port (u16) of SocketAddress