#[non_exhaustive]pub enum ProxyRouteFailureCacheScope {
PerDestination,
PerProxy,
}Available on crate feature
std only.Expand description
Scope used to identify temporarily failing proxy routes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PerDestination
Keep failures isolated per proxy route and final destination.
PerProxy
Share failures for a proxy route across every final destination.