pub struct MultiplexPool<C, ID> { /* private fields */ }std only.Expand description
Connection pool that multiplexes concurrent users over shared connections.
Implementations
Sourceimpl<C, ID> MultiplexPool<C, ID>
impl<C, ID> MultiplexPool<C, ID>
Sourcepub fn new(
max_concurrent_streams: NonZeroUsize,
max_total: NonZeroUsize,
) -> Self
pub fn new( max_concurrent_streams: NonZeroUsize, max_total: NonZeroUsize, ) -> Self
Create a new MultiplexPool from validated, non-zero limits.
Sourcepub fn try_new(
max_concurrent_streams: usize,
max_total: usize,
) -> Result<Self, BoxError>
pub fn try_new( max_concurrent_streams: usize, max_total: usize, ) -> Result<Self, BoxError>
Create a new MultiplexPool.
max_concurrent_streams: upper bound on the concurrent users a single connection serves. The actual per-connection concurrency is the minimum of this and the connection’sMaxConcurrencyextension (usize::MAXif unset), so useusize::MAXto defer entirely to what each connection advertises.max_total: max number of connections (across all ids).
Sourcepub fn maybe_with_idle_timeout(self, timeout: Option<Duration>) -> Self
pub fn maybe_with_idle_timeout(self, timeout: Option<Duration>) -> Self
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
Sourcepub fn maybe_set_idle_timeout(&mut self, timeout: Option<Duration>) -> &mut Self
pub fn maybe_set_idle_timeout(&mut self, timeout: Option<Duration>) -> &mut Self
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
Sourcepub fn with_idle_timeout(self, timeout: Duration) -> Self
pub fn with_idle_timeout(self, timeout: Duration) -> Self
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
Sourcepub fn set_idle_timeout(&mut self, timeout: Duration) -> &mut Self
pub fn set_idle_timeout(&mut self, timeout: Duration) -> &mut Self
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
Sourcepub fn without_idle_timeout(self) -> Self
pub fn without_idle_timeout(self) -> Self
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
Sourcepub fn unset_idle_timeout(&mut self) -> &mut Self
pub fn unset_idle_timeout(&mut self) -> &mut Self
Drop connections that have been idle (no active streams) for longer than the given timeout. Only checked when a connection is requested.
Sourcepub fn with_selection(self, selection: MuxSelection) -> Self
pub fn with_selection(self, selection: MuxSelection) -> Self
Set the MuxSelection strategy used to pick among same-id connections.
Sourcepub fn set_selection(&mut self, selection: MuxSelection) -> &mut Self
pub fn set_selection(&mut self, selection: MuxSelection) -> &mut Self
Set the MuxSelection strategy used to pick among same-id connections.
pub fn maybe_with_metrics(self, metrics: Option<Arc<PoolMetrics>>) -> Self
opentelemetry only.pub fn maybe_set_metrics( &mut self, metrics: Option<Arc<PoolMetrics>>, ) -> &mut Self
opentelemetry only.pub fn with_metrics(self, metrics: Arc<PoolMetrics>) -> Self
opentelemetry only.pub fn set_metrics(&mut self, metrics: Arc<PoolMetrics>) -> &mut Self
opentelemetry only.pub fn without_metrics(self) -> Self
opentelemetry only.pub fn unset_metrics(&mut self) -> &mut Self
opentelemetry only.Trait Implementations
Sourceimpl<C, ID> Clone for MultiplexPool<C, ID>
impl<C, ID> Clone for MultiplexPool<C, ID>
Sourceimpl<C, ID> Debug for MultiplexPool<C, ID>
impl<C, ID> Debug for MultiplexPool<C, ID>
impl<C, ID> Extension for MultiplexPool<C, ID>
impl<C, ID> NetExtension for MultiplexPool<C, ID>
Sourceimpl<C, ID> Pool<C, ID> for MultiplexPool<C, ID>
impl<C, ID> Pool<C, ID> for MultiplexPool<C, ID>
type Connection = MultiplexedConnection<C, ID>
type CreatePermit = PoolSlot
Sourceasync fn get_conn(
&self,
id: &ID,
) -> Result<ConnectionResult<Self::Connection, Self::CreatePermit>, BoxError>
async fn get_conn( &self, id: &ID, ) -> Result<ConnectionResult<Self::Connection, Self::CreatePermit>, BoxError>
Pool::CreatePermit is returned Read moreAuto Trait Implementations
impl<C, ID> !RefUnwindSafe for MultiplexPool<C, ID>
impl<C, ID> !UnwindSafe for MultiplexPool<C, ID>
impl<C, ID> Freeze for MultiplexPool<C, ID>
impl<C, ID> Send for MultiplexPool<C, ID>
impl<C, ID> Sync for MultiplexPool<C, ID>
impl<C, ID> Unpin for MultiplexPool<C, ID>
impl<C, ID> UnsafeUnpin for MultiplexPool<C, ID>