pub struct MultiplexedConnection<C, ID> { /* private fields */ }Available on crate feature
std only.Expand description
A cheap handle to a shared connection in a MultiplexPool.
It implements Service by forwarding to the inner connection and counts as
one of the connection’s in-flight streams for its lifetime, the stream is
released on drop.