FallbackHttpVersion

Struct FallbackHttpVersion 

pub struct FallbackHttpVersion(pub Version);
Available on crate feature http only.
HTTP version to use only when connection negotiation does not select one.

Unlike TargetHttpVersion, this is not an egress requirement and must not constrain TLS ALPN. It becomes the target only after the transport has been established without negotiating an HTTP version.

Tuple Fields

0: Version