pub struct UsernameLabelParserLayer<P> { /* private fields */ }Expand description
Layer which can be used to add parser capabilities to any service
stack which injects a UserId into the input.
For most use-cases you do not need this layer at all. Http and socks5 support by rama already can handle parsers out of the box:
- for the http proxy you can do it directly within the proxy acceptor layer;
- for the socks5 proxy you would do the parsing as part of your authorizer implementation.
If this is not the case you will have to add username label capabilities to your authorizer. Sadly not all authorizer traits allow adding extensions. This is probably a shortcoming which should be fixed at some point. Feel free to feature request this.
Implementations
Sourceimpl<P> UsernameLabelParserLayer<P>
impl<P> UsernameLabelParserLayer<P>