pub struct Basic { /* private fields */ }Expand description
Basic credentials.
Implementations
Sourceimpl Basic
impl Basic
Sourcepub const fn new(username: NonEmptyStr, password: NonEmptyStr) -> Self
pub const fn new(username: NonEmptyStr, password: NonEmptyStr) -> Self
Creates a new Basic credential.
pub fn clone_with_new_username(&self, username: NonEmptyStr) -> Self
pub fn clone_with_new_password(&self, password: NonEmptyStr) -> Self
Sourcepub const fn new_insecure(username: NonEmptyStr) -> Self
pub const fn new_insecure(username: NonEmptyStr) -> Self
Creates a new Basic credential.
Sourcepub fn with_username(self, username: NonEmptyStr) -> Self
pub fn with_username(self, username: NonEmptyStr) -> Self
Set or overwrite the username with the given value.
Sourcepub fn set_username(&mut self, username: NonEmptyStr) -> &mut Self
pub fn set_username(&mut self, username: NonEmptyStr) -> &mut Self
Set or overwrite the username with the given value.
Sourcepub fn password(&self) -> Option<&str>
pub fn password(&self) -> Option<&str>
View the decoded password.
If Some(str) is returned it is guaranteed to be non-empty.
Sourcepub fn with_password(self, password: NonEmptyStr) -> Self
pub fn with_password(self, password: NonEmptyStr) -> Self
Set or overwrite the password with the given value.
Sourcepub fn set_password(&mut self, password: NonEmptyStr) -> &mut Self
pub fn set_password(&mut self, password: NonEmptyStr) -> &mut Self
Set or overwrite the password with the given value.
Turn itself into a StaticAuthorizer, so it can be used to authorize.
Just a shortcut, QoL.