pub struct FallbackHttpVersion(pub Version);Available on crate feature
http only.Expand description
HTTP version to use only when connection negotiation does not select one.
Unlike TargetHttpVersion, this is not an egress requirement and must not
constrain TLS ALPN. It becomes the target only after the transport has been
established without negotiating an HTTP version.
Tuple Fields
0: VersionTrait Implementations
Sourceimpl Clone for FallbackHttpVersion
impl Clone for FallbackHttpVersion
Sourcefn clone(&self) -> FallbackHttpVersion
fn clone(&self) -> FallbackHttpVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FallbackHttpVersion
Sourceimpl Debug for FallbackHttpVersion
impl Debug for FallbackHttpVersion
Sourceimpl Default for FallbackHttpVersion
impl Default for FallbackHttpVersion
Sourcefn default() -> FallbackHttpVersion
fn default() -> FallbackHttpVersion
Returns the “default value” for a type. Read more
impl Eq for FallbackHttpVersion
impl Extension for FallbackHttpVersion
impl HttpExtension for FallbackHttpVersion
Sourceimpl PartialEq for FallbackHttpVersion
impl PartialEq for FallbackHttpVersion
impl StructuralPartialEq for FallbackHttpVersion