pub struct IdleGuard { /* private fields */ }Available on crate feature
std only.Expand description
A resettable idle deadline.
Designed to be used as one arm of a tokio::select!: poll IdleGuard::tick
in the select; when another arm fires (i.e. progress was observed) call
IdleGuard::reset before re-entering the select to extend the idle window.
If the inner Sleep elapses before reset is called,
the idle window has lapsed.
IdleGuard is intended for cases where the watched activity does not itself
produce values that can be selected on (e.g. byte progress observed inside
another future). For values that can be selected on, prefer racing the
activity directly.
Implementations
Sourceimpl IdleGuard
impl IdleGuard